summaryrefslogtreecommitdiffstats
path: root/groovy
diff options
context:
space:
mode:
authorJohn Crygier <john.crygier@aon.com>2012-03-31 02:22:18 +0800
committerJames Moger <james.moger@gitblit.com>2012-03-31 20:32:16 +0800
commita612e6af36c9c2bd2ef81d9c1697ce1543a1a9df (patch)
tree21cc19acb546af7422536f1b90ff3456d30efb52 /groovy
parent332e93c9e8b2ef756ac2b2ec1055262046f988fa (diff)
downloadgitblit-a612e6af36c9c2bd2ef81d9c1697ce1543a1a9df.tar.gz
gitblit-a612e6af36c9c2bd2ef81d9c1697ce1543a1a9df.zip
Add ClientLogger so scripts can log info / warning messages to the pushing client.
Diffstat (limited to 'groovy')
-rw-r--r--groovy/blockpush.groovy14
1 files changed, 8 insertions, 6 deletions
diff --git a/groovy/blockpush.groovy b/groovy/blockpush.groovy
index a4cede3e..79d696c1 100644
--- a/groovy/blockpush.groovy
+++ b/groovy/blockpush.groovy
@@ -21,6 +21,7 @@ import com.gitblit.models.UserModel
import org.eclipse.jgit.transport.ReceiveCommand
import org.eclipse.jgit.transport.ReceiveCommand.Result
import org.slf4j.Logger
+import com.gitblit.utils.ClientLogger
/**
* Sample Gitblit Pre-Receive Hook: blockpush
@@ -50,12 +51,13 @@ import org.slf4j.Logger
* chain, "return false" at the appropriate failure points.
*
* Bound Variables:
* gitblit Gitblit Server com.gitblit.GitBlit
* repository Gitblit Repository com.gitblit.models.RepositoryModel
* user Gitblit User com.gitblit.models.UserModel
* commands JGit commands Collection<org.eclipse.jgit.transport.ReceiveCommand>
* url Base url for Gitblit String
* log Logger instance org.slf4j.Logger
*
*/
@@ -50,12 +51,13 @@ import org.slf4j.Logger
*
* Bound Variables:
- * gitblit Gitblit Server com.gitblit.GitBlit
- * repository Gitblit Repository com.gitblit.models.RepositoryModel
- * user Gitblit User com.gitblit.models.UserModel
- * commands JGit commands Collection<org.eclipse.jgit.transport.ReceiveCommand>
- * url Base url for Gitblit String
- * log Logger instance org.slf4j.Logger
+ * gitblit Gitblit Server com.gitblit.GitBlit
+ * repository Gitblit Repository com.gitblit.models.RepositoryModel
+ * user Gitblit User com.gitblit.models.UserModel
+ * clientLogger Logs messages to client com.gitblit.utils.ClientLogger
+ * commands JGit commands Collection<org.eclipse.jgit.transport.ReceiveCommand>
+ * url Base url for Gitblit String
+ * logger Logger instance org.slf4j.Logger
*
*/